==> screwdriver-cd-python-sdk-0.0.8.tar.gz: screwdriver-cd-python-sdk-0.0.8/README.md <==
Screwdriver CD Python SDK
=========================

![Python Version][Python Version Badge]
[![PyPI][PyPI project badge]][PyPI project url]
[![GitHub Workflow Status][GitHub Workflow Status badge]][GitHub Workflow Status url]

Documentation
-------------

Coming soon

Troubleshooting
---------------

### PyCharm Doesn't Detect Newly Installed screwdriver-cd-python-sdk

Simply close your project and open it with PyCharm again. The re-indexing should make it work

License
-------

The use and distribution terms for Screwdriver CD Python SDK are covered by the [Apache License, Version 2.0].

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://github.com/QubitPi/QubitPi/blob/master/img/apache-2.png?raw=true">
    </a>
</div>

[Apache License, Version 2.0]: http://www.apache.org/licenses/LICENSE-2.0.html

[GitHub Workflow Status badge]: https://img.shields.io/github/actions/workflow/status/QubitPi/screwdriver-cd-python-sdk/ci-cd.yml?logo=github&style=for-the-badge
[GitHub Workflow Status url]: https://github.com/QubitPi/screwdriver-cd-python-sdk/actions/workflows/ci-cd.yml

[Python Version Badge]: https://img.shields.io/badge/Python-3.10-brightgreen?style=for-the-badge&logo=python&logoColor=white
[PyPI project badge]: https://img.shields.io/pypi/v/screwdriver-cd-python-sdk?logo=pypi&logoColor=white&style=for-the-badge
[PyPI project url]: https://pypi.org/project/screwdriver-cd-python-sdk/

==> screwdriver-cd-python-sdk-1.0.0.tar.gz: screwdriver-cd-python-sdk-1.0.0/README.md <==
Screwdriver CD Python SDK
=========================

![Python Version][Python Version Badge]
[![PyPI][PyPI project badge]][PyPI project url]
[![GitHub Workflow Status][GitHub Workflow Status badge]][GitHub Workflow Status URL]
[![Apache License badge]][Apache License URL]

Documentation
-------------

Coming soon

Troubleshooting
---------------

### PyCharm Doesn't Detect Newly Installed screwdriver-cd-python-sdk

Simply close your project and open it with PyCharm again. The re-indexing should make it work

License
-------

The use and distribution terms for Screwdriver CD Python SDK are covered by the [Apache License, Version 2.0].

<div align="center">
    <a href="https://opensource.org/licenses">
        <img align="center" width="50%" alt="License Illustration" src="https://github.com/QubitPi/QubitPi/blob/master/img/apache-2.png?raw=true">
    </a>
</div>

[Apache License badge]: https://img.shields.io/badge/Apache%202.0-F25910.svg?style=for-the-badge&logo=Apache&logoColor=white
[Apache License URL]: https://www.apache.org/licenses/LICENSE-2.0
[Apache License, Version 2.0]: http://www.apache.org/licenses/LICENSE-2.0.html

[GitHub Workflow Status badge]: https://img.shields.io/github/actions/workflow/status/QubitPi/screwdriver-cd-python-sdk/ci-cd.yml?logo=github&style=for-the-badge
[GitHub Workflow Status URL]: https://github.com/QubitPi/screwdriver-cd-python-sdk/actions/workflows/ci-cd.yml

[Python Version Badge]: https://img.shields.io/badge/Python-3.10-brightgreen?style=for-the-badge&logo=python&logoColor=white
[PyPI project badge]: https://img.shields.io/pypi/v/screwdriver-cd-python-sdk?logo=pypi&logoColor=white&style=for-the-badge
[PyPI project url]: https://pypi.org/project/screwdriver-cd-python-sdk/
